{% if component.get_rendered_object %}
    <dl {% if component.horizontal %}class="dl-horizontal"{% endif %}>
        {% for field in component.get_rendered_object %}
            <dt>{{ field.label }}</dt>
            <dd class="description-value">{{ field.value|safe }}</dd>
        {% endfor %}
    </dl>
{% elif component.no_data_message %}
    <div class="alert alert-default no-margin flat">
        {{ component.no_data_message }}
    </div>
{% endif %}