"""
trionyx.data.currencies
~~~~~~~~~~~~~~~~~~~~~~~

:copyright: 2019 by Maikel Martens
:license: GPLv3
"""
CURRENCIES = (
    ("AFN", "Afghani"),
    ("EUR", "Euro"),
    ("ALL", "Lek"),
    ("DZD", "Algerian Dinar"),
    ("USD", "US Dollar"),
    ("AOA", "Kwanza"),
    ("ARS", "Argentine Peso"),
    ("AMD", "Armenian Dram"),
    ("AWG", "Aruban Florin"),
    ("AUD", "Australian Dollar"),
    ("AZN", "Azerbaijan Manat"),
    ("BSD", "Bahamian Dollar"),
    ("BHD", "Bahraini Dinar"),
    ("BDT", "Taka"),
    ("BBD", "Barbados Dollar"),
    ("BYN", "Belarusian Ruble"),
    ("BZD", "Belize Dollar"),
    ("BMD", "Bermudian Dollar"),
    ("INR", "Indian Rupee"),
    ("BTN", "Ngultrum"),
    ("BOB", "Boliviano"),
    ("BOV", "Mvdol"),
    ("BAM", "Convertible Mark"),
    ("BWP", "Pula"),
    ("NOK", "Norwegian Krone"),
    ("BRL", "Brazilian Real"),
    ("BND", "Brunei Dollar"),
    ("BGN", "Bulgarian Lev"),
    ("BIF", "Burundi Franc"),
    ("CVE", "Cabo Verde Escudo"),
    ("KHR", "Riel"),
    ("CAD", "Canadian Dollar"),
    ("KYD", "Cayman Islands Dollar"),
    ("CLP", "Chilean Peso"),
    ("CLF", "Unidad de Fomento"),
    ("CNY", "Yuan Renminbi"),
    ("COP", "Colombian Peso"),
    ("COU", "Unidad de Valor Real"),
    ("KMF", "Comorian Franc "),
    ("CDF", "Congolese Franc"),
    ("NZD", "New Zealand Dollar"),
    ("CRC", "Costa Rican Colon"),
    ("HRK", "Kuna"),
    ("CUP", "Cuban Peso"),
    ("CUC", "Peso Convertible"),
    ("ANG", "Netherlands Antillean Guilder"),
    ("CZK", "Czech Koruna"),
    ("DKK", "Danish Krone"),
    ("DJF", "Djibouti Franc"),
    ("DOP", "Dominican Peso"),
    ("EGP", "Egyptian Pound"),
    ("SVC", "El Salvador Colon"),
    ("ERN", "Nakfa"),
    ("ETB", "Ethiopian Birr"),
    ("FKP", "Falkland Islands Pound"),
    ("FJD", "Fiji Dollar"),
    ("GMD", "Dalasi"),
    ("GEL", "Lari"),
    ("GHS", "Ghana Cedi"),
    ("GIP", "Gibraltar Pound"),
    ("GTQ", "Quetzal"),
    ("GBP", "Pound Sterling"),
    ("GNF", "Guinean Franc"),
    ("GYD", "Guyana Dollar"),
    ("HTG", "Gourde"),
    ("HNL", "Lempira"),
    ("HKD", "Hong Kong Dollar"),
    ("HUF", "Forint"),
    ("ISK", "Iceland Krona"),
    ("IDR", "Rupiah"),
    ("IRR", "Iranian Rial"),
    ("IQD", "Iraqi Dinar"),
    ("ILS", "New Israeli Sheqel"),
    ("JMD", "Jamaican Dollar"),
    ("JPY", "Yen"),
    ("JOD", "Jordanian Dinar"),
    ("KZT", "Tenge"),
    ("KES", "Kenyan Shilling"),
    ("KPW", "North Korean Won"),
    ("KRW", "Won"),
    ("KWD", "Kuwaiti Dinar"),
    ("KGS", "Som"),
    ("LAK", "Lao Kip"),
    ("LBP", "Lebanese Pound"),
    ("LSL", "Loti"),
    ("ZAR", "Rand"),
    ("LRD", "Liberian Dollar"),
    ("LYD", "Libyan Dinar"),
    ("CHF", "Swiss Franc"),
    ("MOP", "Pataca"),
    ("MKD", "Denar"),
    ("MGA", "Malagasy Ariary"),
    ("MWK", "Malawi Kwacha"),
    ("MYR", "Malaysian Ringgit"),
    ("MVR", "Rufiyaa"),
    ("MRU", "Ouguiya"),
    ("MUR", "Mauritius Rupee"),
    ("MXN", "Mexican Peso"),
    ("MXV", "Mexican Unidad de Inversion (UDI)"),
    ("MDL", "Moldovan Leu"),
    ("MNT", "Tugrik"),
    ("MAD", "Moroccan Dirham"),
    ("MZN", "Mozambique Metical"),
    ("MMK", "Kyat"),
    ("NAD", "Namibia Dollar"),
    ("NPR", "Nepalese Rupee"),
    ("NIO", "Cordoba Oro"),
    ("NGN", "Naira"),
    ("OMR", "Rial Omani"),
    ("PKR", "Pakistan Rupee"),
    ("PAB", "Balboa"),
    ("PGK", "Kina"),
    ("PYG", "Guarani"),
    ("PEN", "Sol"),
    ("PHP", "Philippine Peso"),
    ("PLN", "Zloty"),
    ("QAR", "Qatari Rial"),
    ("RON", "Romanian Leu"),
    ("RUB", "Russian Ruble"),
    ("RWF", "Rwanda Franc"),
    ("SHP", "Saint Helena Pound"),
    ("WST", "Tala"),
    ("STN", "Dobra"),
    ("SAR", "Saudi Riyal"),
    ("RSD", "Serbian Dinar"),
    ("SCR", "Seychelles Rupee"),
    ("SLL", "Leone"),
    ("SGD", "Singapore Dollar"),
    ("SBD", "Solomon Islands Dollar"),
    ("SOS", "Somali Shilling"),
    ("SSP", "South Sudanese Pound"),
    ("LKR", "Sri Lanka Rupee"),
    ("SDG", "Sudanese Pound"),
    ("SRD", "Surinam Dollar"),
    ("SZL", "Lilangeni"),
    ("SEK", "Swedish Krona"),
    ("CHE", "WIR Euro"),
    ("CHW", "WIR Franc"),
    ("SYP", "Syrian Pound"),
    ("TWD", "New Taiwan Dollar"),
    ("TJS", "Somoni"),
    ("TZS", "Tanzanian Shilling"),
    ("THB", "Baht"),
    ("TOP", "Pa’anga"),
    ("TTD", "Trinidad and Tobago Dollar"),
    ("TND", "Tunisian Dinar"),
    ("TRY", "Turkish Lira"),
    ("TMT", "Turkmenistan New Manat"),
    ("UGX", "Uganda Shilling"),
    ("UAH", "Hryvnia"),
    ("AED", "UAE Dirham"),
    ("USN", "US Dollar (Next day)"),
    ("UYU", "Peso Uruguayo"),
    ("UYI", "Uruguay Peso en Unidades Indexadas (UI)"),
    ("UZS", "Uzbekistan Sum"),
    ("VUV", "Vatu"),
    ("VEF", "Bolívar"),
    ("VND", "Dong"),
    ("YER", "Yemeni Rial"),
    ("ZMW", "Zambian Kwacha"),
    ("ZWL", "Zimbabwe Dollar"),
)
