{% load trionyx %}
<div>
    <div class="panel panel-{% if component.contextual %}{{ component.contextual }}{% else %}default{% endif %}">
        <div class="panel-heading">{% if component.title %}{{ component.title }}{% else %}{{component.object}}{% endif %}</div>
        <div class="{% if component.collapse %}panel-collapse{% else %}panel-body{% endif %}">
            {% for child in component.components %}
                {% render_component child %}
            {% endfor %}
        </div>
        {% if component.footer_components %}
            {% for child in component.footer_components %}
                {% render_component child %}
            {% endfor %}
        {% endif %}
    </div>
</div>
