"""
trionyx.trionyx.icons
~~~~~~~~~~~~~~~~~~~~~

:copyright: 2019 by Maikel Martens
:license: GPLv3
"""
ICON_CHOICES = [
    ('fa fa-dashboard', '<i class="fa fa-dashboard"></i> Dashboard'),
    ('fa fa-500px', '<i class="fa fa-500px"></i> 500px'),
    ('fa fa-amazon', '<i class="fa fa-amazon"></i> Amazon'),
    ('fa fa-balance-scale', '<i class="fa fa-balance-scale"></i> Balance-scale'),
    ('fa fa-battery-0', '<i class="fa fa-battery-0"></i> Battery-0'),
    ('fa fa-battery-1', '<i class="fa fa-battery-1"></i> Battery-1'),
    ('fa fa-battery-2', '<i class="fa fa-battery-2"></i> Battery-2'),
    ('fa fa-battery-3', '<i class="fa fa-battery-3"></i> Battery-3'),
    ('fa fa-battery-4', '<i class="fa fa-battery-4"></i> Battery-4'),
    ('fa fa-battery-empty', '<i class="fa fa-battery-empty"></i> Battery-empty'),
    ('fa fa-battery-full', '<i class="fa fa-battery-full"></i> Battery-full'),
    ('fa fa-battery-half', '<i class="fa fa-battery-half"></i> Battery-half'),
    ('fa fa-battery-quarter', '<i class="fa fa-battery-quarter"></i> Battery-quarter'),
    ('fa fa-battery-three-quarters', '<i class="fa fa-battery-three-quarters"></i> Battery-three-quarters'),
    ('fa fa-black-tie', '<i class="fa fa-black-tie"></i> Black-tie'),
    ('fa fa-calendar-check-o', '<i class="fa fa-calendar-check-o"></i> Calendar-check-o'),
    ('fa fa-calendar-minus-o', '<i class="fa fa-calendar-minus-o"></i> Calendar-minus-o'),
    ('fa fa-calendar-plus-o', '<i class="fa fa-calendar-plus-o"></i> Calendar-plus-o'),
    ('fa fa-calendar-times-o', '<i class="fa fa-calendar-times-o"></i> Calendar-times-o'),
    ('fa fa-cc-diners-club', '<i class="fa fa-cc-diners-club"></i> Cc-diners-club'),
    ('fa fa-cc-jcb', '<i class="fa fa-cc-jcb"></i> Cc-jcb'),
    ('fa fa-chrome', '<i class="fa fa-chrome"></i> Chrome'),
    ('fa fa-clone', '<i class="fa fa-clone"></i> Clone'),
    ('fa fa-commenting', '<i class="fa fa-commenting"></i> Commenting'),
    ('fa fa-commenting-o', '<i class="fa fa-commenting-o"></i> Commenting-o'),
    ('fa fa-contao', '<i class="fa fa-contao"></i> Contao'),
    ('fa fa-creative-commons', '<i class="fa fa-creative-commons"></i> Creative-commons'),
    ('fa fa-expeditedssl', '<i class="fa fa-expeditedssl"></i> Expeditedssl'),
    ('fa fa-firefox', '<i class="fa fa-firefox"></i> Firefox'),
    ('fa fa-fonticons', '<i class="fa fa-fonticons"></i> Fonticons'),
    ('fa fa-genderless', '<i class="fa fa-genderless"></i> Genderless'),
    ('fa fa-get-pocket', '<i class="fa fa-get-pocket"></i> Get-pocket'),
    ('fa fa-gg', '<i class="fa fa-gg"></i> Gg'),
    ('fa fa-gg-circle', '<i class="fa fa-gg-circle"></i> Gg-circle'),
    ('fa fa-hand-grab-o', '<i class="fa fa-hand-grab-o"></i> Hand-grab-o'),
    ('fa fa-hand-lizard-o', '<i class="fa fa-hand-lizard-o"></i> Hand-lizard-o'),
    ('fa fa-hand-paper-o', '<i class="fa fa-hand-paper-o"></i> Hand-paper-o'),
    ('fa fa-hand-peace-o', '<i class="fa fa-hand-peace-o"></i> Hand-peace-o'),
    ('fa fa-hand-pointer-o', '<i class="fa fa-hand-pointer-o"></i> Hand-pointer-o'),
    ('fa fa-hand-rock-o', '<i class="fa fa-hand-rock-o"></i> Hand-rock-o'),
    ('fa fa-hand-scissors-o', '<i class="fa fa-hand-scissors-o"></i> Hand-scissors-o'),
    ('fa fa-hand-spock-o', '<i class="fa fa-hand-spock-o"></i> Hand-spock-o'),
    ('fa fa-hand-stop-o', '<i class="fa fa-hand-stop-o"></i> Hand-stop-o'),
    ('fa fa-hourglass', '<i class="fa fa-hourglass"></i> Hourglass'),
    ('fa fa-hourglass-1', '<i class="fa fa-hourglass-1"></i> Hourglass-1'),
    ('fa fa-hourglass-2', '<i class="fa fa-hourglass-2"></i> Hourglass-2'),
    ('fa fa-hourglass-3', '<i class="fa fa-hourglass-3"></i> Hourglass-3'),
    ('fa fa-hourglass-end', '<i class="fa fa-hourglass-end"></i> Hourglass-end'),
    ('fa fa-hourglass-half', '<i class="fa fa-hourglass-half"></i> Hourglass-half'),
    ('fa fa-hourglass-o', '<i class="fa fa-hourglass-o"></i> Hourglass-o'),
    ('fa fa-hourglass-start', '<i class="fa fa-hourglass-start"></i> Hourglass-start'),
    ('fa fa-houzz', '<i class="fa fa-houzz"></i> Houzz'),
    ('fa fa-i-cursor', '<i class="fa fa-i-cursor"></i> I-cursor'),
    ('fa fa-industry', '<i class="fa fa-industry"></i> Industry'),
    ('fa fa-internet-explorer', '<i class="fa fa-internet-explorer"></i> Internet-explorer'),
    ('fa fa-map', '<i class="fa fa-map"></i> Map'),
    ('fa fa-map-o', '<i class="fa fa-map-o"></i> Map-o'),
    ('fa fa-map-pin', '<i class="fa fa-map-pin"></i> Map-pin'),
    ('fa fa-map-signs', '<i class="fa fa-map-signs"></i> Map-signs'),
    ('fa fa-mouse-pointer', '<i class="fa fa-mouse-pointer"></i> Mouse-pointer'),
    ('fa fa-object-group', '<i class="fa fa-object-group"></i> Object-group'),
    ('fa fa-object-ungroup', '<i class="fa fa-object-ungroup"></i> Object-ungroup'),
    ('fa fa-odnoklassniki', '<i class="fa fa-odnoklassniki"></i> Odnoklassniki'),
    ('fa fa-odnoklassniki-square', '<i class="fa fa-odnoklassniki-square"></i> Odnoklassniki-square'),
    ('fa fa-opencart', '<i class="fa fa-opencart"></i> Opencart'),
    ('fa fa-opera', '<i class="fa fa-opera"></i> Opera'),
    ('fa fa-optin-monster', '<i class="fa fa-optin-monster"></i> Optin-monster'),
    ('fa fa-registered', '<i class="fa fa-registered"></i> Registered'),
    ('fa fa-safari', '<i class="fa fa-safari"></i> Safari'),
    ('fa fa-sticky-note', '<i class="fa fa-sticky-note"></i> Sticky-note'),
    ('fa fa-sticky-note-o', '<i class="fa fa-sticky-note-o"></i> Sticky-note-o'),
    ('fa fa-television', '<i class="fa fa-television"></i> Television'),
    ('fa fa-trademark', '<i class="fa fa-trademark"></i> Trademark'),
    ('fa fa-tripadvisor', '<i class="fa fa-tripadvisor"></i> Tripadvisor'),
    ('fa fa-tv', '<i class="fa fa-tv"></i> Tv'),
    ('fa fa-vimeo', '<i class="fa fa-vimeo"></i> Vimeo'),
    ('fa fa-wikipedia-w', '<i class="fa fa-wikipedia-w"></i> Wikipedia-w'),
    ('fa fa-y-combinator', '<i class="fa fa-y-combinator"></i> Y-combinator'),
    ('fa fa-yc', '<i class="fa fa-yc"></i> Yc'),
    ('fa fa-adjust', '<i class="fa fa-adjust"></i> Adjust'),
    ('fa fa-anchor', '<i class="fa fa-anchor"></i> Anchor'),
    ('fa fa-archive', '<i class="fa fa-archive"></i> Archive'),
    ('fa fa-area-chart', '<i class="fa fa-area-chart"></i> Area-chart'),
    ('fa fa-arrows', '<i class="fa fa-arrows"></i> Arrows'),
    ('fa fa-arrows-h', '<i class="fa fa-arrows-h"></i> Arrows-h'),
    ('fa fa-arrows-v', '<i class="fa fa-arrows-v"></i> Arrows-v'),
    ('fa fa-asterisk', '<i class="fa fa-asterisk"></i> Asterisk'),
    ('fa fa-at', '<i class="fa fa-at"></i> At'),
    ('fa fa-automobile', '<i class="fa fa-automobile"></i> Automobile'),
    ('fa fa-ban', '<i class="fa fa-ban"></i> Ban'),
    ('fa fa-bank', '<i class="fa fa-bank"></i> Bank'),
    ('fa fa-bar-chart', '<i class="fa fa-bar-chart"></i> Bar-chart'),
    ('fa fa-bar-chart-o', '<i class="fa fa-bar-chart-o"></i> Bar-chart-o'),
    ('fa fa-barcode', '<i class="fa fa-barcode"></i> Barcode'),
    ('fa fa-bars', '<i class="fa fa-bars"></i> Bars'),
    ('fa fa-bed', '<i class="fa fa-bed"></i> Bed'),
    ('fa fa-beer', '<i class="fa fa-beer"></i> Beer'),
    ('fa fa-bell', '<i class="fa fa-bell"></i> Bell'),
    ('fa fa-bell-o', '<i class="fa fa-bell-o"></i> Bell-o'),
    ('fa fa-bell-slash', '<i class="fa fa-bell-slash"></i> Bell-slash'),
    ('fa fa-bell-slash-o', '<i class="fa fa-bell-slash-o"></i> Bell-slash-o'),
    ('fa fa-bicycle', '<i class="fa fa-bicycle"></i> Bicycle'),
    ('fa fa-binoculars', '<i class="fa fa-binoculars"></i> Binoculars'),
    ('fa fa-birthday-cake', '<i class="fa fa-birthday-cake"></i> Birthday-cake'),
    ('fa fa-bolt', '<i class="fa fa-bolt"></i> Bolt'),
    ('fa fa-bomb', '<i class="fa fa-bomb"></i> Bomb'),
    ('fa fa-book', '<i class="fa fa-book"></i> Book'),
    ('fa fa-bookmark', '<i class="fa fa-bookmark"></i> Bookmark'),
    ('fa fa-bookmark-o', '<i class="fa fa-bookmark-o"></i> Bookmark-o'),
    ('fa fa-briefcase', '<i class="fa fa-briefcase"></i> Briefcase'),
    ('fa fa-bug', '<i class="fa fa-bug"></i> Bug'),
    ('fa fa-building', '<i class="fa fa-building"></i> Building'),
    ('fa fa-building-o', '<i class="fa fa-building-o"></i> Building-o'),
    ('fa fa-bullhorn', '<i class="fa fa-bullhorn"></i> Bullhorn'),
    ('fa fa-bullseye', '<i class="fa fa-bullseye"></i> Bullseye'),
    ('fa fa-bus', '<i class="fa fa-bus"></i> Bus'),
    ('fa fa-cab', '<i class="fa fa-cab"></i> Cab'),
    ('fa fa-calculator', '<i class="fa fa-calculator"></i> Calculator'),
    ('fa fa-calendar', '<i class="fa fa-calendar"></i> Calendar'),
    ('fa fa-calendar-o', '<i class="fa fa-calendar-o"></i> Calendar-o'),
    ('fa fa-camera', '<i class="fa fa-camera"></i> Camera'),
    ('fa fa-camera-retro', '<i class="fa fa-camera-retro"></i> Camera-retro'),
    ('fa fa-car', '<i class="fa fa-car"></i> Car'),
    ('fa fa-caret-square-o-down', '<i class="fa fa-caret-square-o-down"></i> Caret-square-o-down'),
    ('fa fa-caret-square-o-left', '<i class="fa fa-caret-square-o-left"></i> Caret-square-o-left'),
    ('fa fa-caret-square-o-right', '<i class="fa fa-caret-square-o-right"></i> Caret-square-o-right'),
    ('fa fa-caret-square-o-up', '<i class="fa fa-caret-square-o-up"></i> Caret-square-o-up'),
    ('fa fa-cart-arrow-down', '<i class="fa fa-cart-arrow-down"></i> Cart-arrow-down'),
    ('fa fa-cart-plus', '<i class="fa fa-cart-plus"></i> Cart-plus'),
    ('fa fa-cc', '<i class="fa fa-cc"></i> Cc'),
    ('fa fa-certificate', '<i class="fa fa-certificate"></i> Certificate'),
    ('fa fa-check', '<i class="fa fa-check"></i> Check'),
    ('fa fa-check-circle', '<i class="fa fa-check-circle"></i> Check-circle'),
    ('fa fa-check-circle-o', '<i class="fa fa-check-circle-o"></i> Check-circle-o'),
    ('fa fa-check-square', '<i class="fa fa-check-square"></i> Check-square'),
    ('fa fa-check-square-o', '<i class="fa fa-check-square-o"></i> Check-square-o'),
    ('fa fa-child', '<i class="fa fa-child"></i> Child'),
    ('fa fa-circle', '<i class="fa fa-circle"></i> Circle'),
    ('fa fa-circle-o', '<i class="fa fa-circle-o"></i> Circle-o'),
    ('fa fa-circle-o-notch', '<i class="fa fa-circle-o-notch"></i> Circle-o-notch'),
    ('fa fa-circle-thin', '<i class="fa fa-circle-thin"></i> Circle-thin'),
    ('fa fa-clock-o', '<i class="fa fa-clock-o"></i> Clock-o'),
    ('fa fa-close', '<i class="fa fa-close"></i> Close'),
    ('fa fa-cloud', '<i class="fa fa-cloud"></i> Cloud'),
    ('fa fa-cloud-download', '<i class="fa fa-cloud-download"></i> Cloud-download'),
    ('fa fa-cloud-upload', '<i class="fa fa-cloud-upload"></i> Cloud-upload'),
    ('fa fa-code', '<i class="fa fa-code"></i> Code'),
    ('fa fa-code-fork', '<i class="fa fa-code-fork"></i> Code-fork'),
    ('fa fa-coffee', '<i class="fa fa-coffee"></i> Coffee'),
    ('fa fa-cog', '<i class="fa fa-cog"></i> Cog'),
    ('fa fa-cogs', '<i class="fa fa-cogs"></i> Cogs'),
    ('fa fa-comment', '<i class="fa fa-comment"></i> Comment'),
    ('fa fa-comment-o', '<i class="fa fa-comment-o"></i> Comment-o'),
    ('fa fa-comments', '<i class="fa fa-comments"></i> Comments'),
    ('fa fa-comments-o', '<i class="fa fa-comments-o"></i> Comments-o'),
    ('fa fa-compass', '<i class="fa fa-compass"></i> Compass'),
    ('fa fa-copyright', '<i class="fa fa-copyright"></i> Copyright'),
    ('fa fa-credit-card', '<i class="fa fa-credit-card"></i> Credit-card'),
    ('fa fa-crop', '<i class="fa fa-crop"></i> Crop'),
    ('fa fa-crosshairs', '<i class="fa fa-crosshairs"></i> Crosshairs'),
    ('fa fa-cube', '<i class="fa fa-cube"></i> Cube'),
    ('fa fa-cubes', '<i class="fa fa-cubes"></i> Cubes'),
    ('fa fa-cutlery', '<i class="fa fa-cutlery"></i> Cutlery'),
    ('fa fa-database', '<i class="fa fa-database"></i> Database'),
    ('fa fa-desktop', '<i class="fa fa-desktop"></i> Desktop'),
    ('fa fa-diamond', '<i class="fa fa-diamond"></i> Diamond'),
    ('fa fa-dot-circle-o', '<i class="fa fa-dot-circle-o"></i> Dot-circle-o'),
    ('fa fa-download', '<i class="fa fa-download"></i> Download'),
    ('fa fa-edit', '<i class="fa fa-edit"></i> Edit'),
    ('fa fa-ellipsis-h', '<i class="fa fa-ellipsis-h"></i> Ellipsis-h'),
    ('fa fa-ellipsis-v', '<i class="fa fa-ellipsis-v"></i> Ellipsis-v'),
    ('fa fa-envelope', '<i class="fa fa-envelope"></i> Envelope'),
    ('fa fa-envelope-o', '<i class="fa fa-envelope-o"></i> Envelope-o'),
    ('fa fa-envelope-square', '<i class="fa fa-envelope-square"></i> Envelope-square'),
    ('fa fa-eraser', '<i class="fa fa-eraser"></i> Eraser'),
    ('fa fa-exchange', '<i class="fa fa-exchange"></i> Exchange'),
    ('fa fa-exclamation', '<i class="fa fa-exclamation"></i> Exclamation'),
    ('fa fa-exclamation-circle', '<i class="fa fa-exclamation-circle"></i> Exclamation-circle'),
    ('fa fa-exclamation-triangle', '<i class="fa fa-exclamation-triangle"></i> Exclamation-triangle'),
    ('fa fa-external-link', '<i class="fa fa-external-link"></i> External-link'),
    ('fa fa-external-link-square', '<i class="fa fa-external-link-square"></i> External-link-square'),
    ('fa fa-eye', '<i class="fa fa-eye"></i> Eye'),
    ('fa fa-eye-slash', '<i class="fa fa-eye-slash"></i> Eye-slash'),
    ('fa fa-eyedropper', '<i class="fa fa-eyedropper"></i> Eyedropper'),
    ('fa fa-fax', '<i class="fa fa-fax"></i> Fax'),
    ('fa fa-feed', '<i class="fa fa-feed"></i> Feed'),
    ('fa fa-female', '<i class="fa fa-female"></i> Female'),
    ('fa fa-fighter-jet', '<i class="fa fa-fighter-jet"></i> Fighter-jet'),
    ('fa fa-file-archive-o', '<i class="fa fa-file-archive-o"></i> File-archive-o'),
    ('fa fa-file-audio-o', '<i class="fa fa-file-audio-o"></i> File-audio-o'),
    ('fa fa-file-code-o', '<i class="fa fa-file-code-o"></i> File-code-o'),
    ('fa fa-file-excel-o', '<i class="fa fa-file-excel-o"></i> File-excel-o'),
    ('fa fa-file-image-o', '<i class="fa fa-file-image-o"></i> File-image-o'),
    ('fa fa-file-movie-o', '<i class="fa fa-file-movie-o"></i> File-movie-o'),
    ('fa fa-file-pdf-o', '<i class="fa fa-file-pdf-o"></i> File-pdf-o'),
    ('fa fa-file-photo-o', '<i class="fa fa-file-photo-o"></i> File-photo-o'),
    ('fa fa-file-picture-o', '<i class="fa fa-file-picture-o"></i> File-picture-o'),
    ('fa fa-file-powerpoint-o', '<i class="fa fa-file-powerpoint-o"></i> File-powerpoint-o'),
    ('fa fa-file-sound-o', '<i class="fa fa-file-sound-o"></i> File-sound-o'),
    ('fa fa-file-video-o', '<i class="fa fa-file-video-o"></i> File-video-o'),
    ('fa fa-file-word-o', '<i class="fa fa-file-word-o"></i> File-word-o'),
    ('fa fa-file-zip-o', '<i class="fa fa-file-zip-o"></i> File-zip-o'),
    ('fa fa-film', '<i class="fa fa-film"></i> Film'),
    ('fa fa-filter', '<i class="fa fa-filter"></i> Filter'),
    ('fa fa-fire', '<i class="fa fa-fire"></i> Fire'),
    ('fa fa-fire-extinguisher', '<i class="fa fa-fire-extinguisher"></i> Fire-extinguisher'),
    ('fa fa-flag', '<i class="fa fa-flag"></i> Flag'),
    ('fa fa-flag-checkered', '<i class="fa fa-flag-checkered"></i> Flag-checkered'),
    ('fa fa-flag-o', '<i class="fa fa-flag-o"></i> Flag-o'),
    ('fa fa-flash', '<i class="fa fa-flash"></i> Flash'),
    ('fa fa-flask', '<i class="fa fa-flask"></i> Flask'),
    ('fa fa-folder', '<i class="fa fa-folder"></i> Folder'),
    ('fa fa-folder-o', '<i class="fa fa-folder-o"></i> Folder-o'),
    ('fa fa-folder-open', '<i class="fa fa-folder-open"></i> Folder-open'),
    ('fa fa-folder-open-o', '<i class="fa fa-folder-open-o"></i> Folder-open-o'),
    ('fa fa-frown-o', '<i class="fa fa-frown-o"></i> Frown-o'),
    ('fa fa-futbol-o', '<i class="fa fa-futbol-o"></i> Futbol-o'),
    ('fa fa-gamepad', '<i class="fa fa-gamepad"></i> Gamepad'),
    ('fa fa-gavel', '<i class="fa fa-gavel"></i> Gavel'),
    ('fa fa-gear', '<i class="fa fa-gear"></i> Gear'),
    ('fa fa-gears', '<i class="fa fa-gears"></i> Gears'),
    ('fa fa-gift', '<i class="fa fa-gift"></i> Gift'),
    ('fa fa-glass', '<i class="fa fa-glass"></i> Glass'),
    ('fa fa-globe', '<i class="fa fa-globe"></i> Globe'),
    ('fa fa-graduation-cap', '<i class="fa fa-graduation-cap"></i> Graduation-cap'),
    ('fa fa-group', '<i class="fa fa-group"></i> Group'),
    ('fa fa-hdd-o', '<i class="fa fa-hdd-o"></i> Hdd-o'),
    ('fa fa-headphones', '<i class="fa fa-headphones"></i> Headphones'),
    ('fa fa-heart', '<i class="fa fa-heart"></i> Heart'),
    ('fa fa-heart-o', '<i class="fa fa-heart-o"></i> Heart-o'),
    ('fa fa-heartbeat', '<i class="fa fa-heartbeat"></i> Heartbeat'),
    ('fa fa-history', '<i class="fa fa-history"></i> History'),
    ('fa fa-home', '<i class="fa fa-home"></i> Home'),
    ('fa fa-hotel', '<i class="fa fa-hotel"></i> Hotel'),
    ('fa fa-image', '<i class="fa fa-image"></i> Image'),
    ('fa fa-inbox', '<i class="fa fa-inbox"></i> Inbox'),
    ('fa fa-info', '<i class="fa fa-info"></i> Info'),
    ('fa fa-info-circle', '<i class="fa fa-info-circle"></i> Info-circle'),
    ('fa fa-institution', '<i class="fa fa-institution"></i> Institution'),
    ('fa fa-key', '<i class="fa fa-key"></i> Key'),
    ('fa fa-keyboard-o', '<i class="fa fa-keyboard-o"></i> Keyboard-o'),
    ('fa fa-language', '<i class="fa fa-language"></i> Language'),
    ('fa fa-laptop', '<i class="fa fa-laptop"></i> Laptop'),
    ('fa fa-leaf', '<i class="fa fa-leaf"></i> Leaf'),
    ('fa fa-legal', '<i class="fa fa-legal"></i> Legal'),
    ('fa fa-lemon-o', '<i class="fa fa-lemon-o"></i> Lemon-o'),
    ('fa fa-level-down', '<i class="fa fa-level-down"></i> Level-down'),
    ('fa fa-level-up', '<i class="fa fa-level-up"></i> Level-up'),
    ('fa fa-life-bouy', '<i class="fa fa-life-bouy"></i> Life-bouy'),
    ('fa fa-life-buoy', '<i class="fa fa-life-buoy"></i> Life-buoy'),
    ('fa fa-life-ring', '<i class="fa fa-life-ring"></i> Life-ring'),
    ('fa fa-life-saver', '<i class="fa fa-life-saver"></i> Life-saver'),
    ('fa fa-lightbulb-o', '<i class="fa fa-lightbulb-o"></i> Lightbulb-o'),
    ('fa fa-line-chart', '<i class="fa fa-line-chart"></i> Line-chart'),
    ('fa fa-location-arrow', '<i class="fa fa-location-arrow"></i> Location-arrow'),
    ('fa fa-lock', '<i class="fa fa-lock"></i> Lock'),
    ('fa fa-magic', '<i class="fa fa-magic"></i> Magic'),
    ('fa fa-magnet', '<i class="fa fa-magnet"></i> Magnet'),
    ('fa fa-mail-forward', '<i class="fa fa-mail-forward"></i> Mail-forward'),
    ('fa fa-mail-reply', '<i class="fa fa-mail-reply"></i> Mail-reply'),
    ('fa fa-mail-reply-all', '<i class="fa fa-mail-reply-all"></i> Mail-reply-all'),
    ('fa fa-male', '<i class="fa fa-male"></i> Male'),
    ('fa fa-map-marker', '<i class="fa fa-map-marker"></i> Map-marker'),
    ('fa fa-meh-o', '<i class="fa fa-meh-o"></i> Meh-o'),
    ('fa fa-microphone', '<i class="fa fa-microphone"></i> Microphone'),
    ('fa fa-microphone-slash', '<i class="fa fa-microphone-slash"></i> Microphone-slash'),
    ('fa fa-minus', '<i class="fa fa-minus"></i> Minus'),
    ('fa fa-minus-circle', '<i class="fa fa-minus-circle"></i> Minus-circle'),
    ('fa fa-minus-square', '<i class="fa fa-minus-square"></i> Minus-square'),
    ('fa fa-minus-square-o', '<i class="fa fa-minus-square-o"></i> Minus-square-o'),
    ('fa fa-mobile', '<i class="fa fa-mobile"></i> Mobile'),
    ('fa fa-mobile-phone', '<i class="fa fa-mobile-phone"></i> Mobile-phone'),
    ('fa fa-money', '<i class="fa fa-money"></i> Money'),
    ('fa fa-moon-o', '<i class="fa fa-moon-o"></i> Moon-o'),
    ('fa fa-mortar-board', '<i class="fa fa-mortar-board"></i> Mortar-board'),
    ('fa fa-motorcycle', '<i class="fa fa-motorcycle"></i> Motorcycle'),
    ('fa fa-music', '<i class="fa fa-music"></i> Music'),
    ('fa fa-navicon', '<i class="fa fa-navicon"></i> Navicon'),
    ('fa fa-newspaper-o', '<i class="fa fa-newspaper-o"></i> Newspaper-o'),
    ('fa fa-paint-brush', '<i class="fa fa-paint-brush"></i> Paint-brush'),
    ('fa fa-paper-plane', '<i class="fa fa-paper-plane"></i> Paper-plane'),
    ('fa fa-paper-plane-o', '<i class="fa fa-paper-plane-o"></i> Paper-plane-o'),
    ('fa fa-paw', '<i class="fa fa-paw"></i> Paw'),
    ('fa fa-pencil', '<i class="fa fa-pencil"></i> Pencil'),
    ('fa fa-pencil-square', '<i class="fa fa-pencil-square"></i> Pencil-square'),
    ('fa fa-pencil-square-o', '<i class="fa fa-pencil-square-o"></i> Pencil-square-o'),
    ('fa fa-phone', '<i class="fa fa-phone"></i> Phone'),
    ('fa fa-phone-square', '<i class="fa fa-phone-square"></i> Phone-square'),
    ('fa fa-photo', '<i class="fa fa-photo"></i> Photo'),
    ('fa fa-picture-o', '<i class="fa fa-picture-o"></i> Picture-o'),
    ('fa fa-pie-chart', '<i class="fa fa-pie-chart"></i> Pie-chart'),
    ('fa fa-plane', '<i class="fa fa-plane"></i> Plane'),
    ('fa fa-plug', '<i class="fa fa-plug"></i> Plug'),
    ('fa fa-plus', '<i class="fa fa-plus"></i> Plus'),
    ('fa fa-plus-circle', '<i class="fa fa-plus-circle"></i> Plus-circle'),
    ('fa fa-plus-square', '<i class="fa fa-plus-square"></i> Plus-square'),
    ('fa fa-plus-square-o', '<i class="fa fa-plus-square-o"></i> Plus-square-o'),
    ('fa fa-power-off', '<i class="fa fa-power-off"></i> Power-off'),
    ('fa fa-print', '<i class="fa fa-print"></i> Print'),
    ('fa fa-puzzle-piece', '<i class="fa fa-puzzle-piece"></i> Puzzle-piece'),
    ('fa fa-qrcode', '<i class="fa fa-qrcode"></i> Qrcode'),
    ('fa fa-question', '<i class="fa fa-question"></i> Question'),
    ('fa fa-question-circle', '<i class="fa fa-question-circle"></i> Question-circle'),
    ('fa fa-quote-left', '<i class="fa fa-quote-left"></i> Quote-left'),
    ('fa fa-quote-right', '<i class="fa fa-quote-right"></i> Quote-right'),
    ('fa fa-random', '<i class="fa fa-random"></i> Random'),
    ('fa fa-recycle', '<i class="fa fa-recycle"></i> Recycle'),
    ('fa fa-refresh', '<i class="fa fa-refresh"></i> Refresh'),
    ('fa fa-remove', '<i class="fa fa-remove"></i> Remove'),
    ('fa fa-reorder', '<i class="fa fa-reorder"></i> Reorder'),
    ('fa fa-reply', '<i class="fa fa-reply"></i> Reply'),
    ('fa fa-reply-all', '<i class="fa fa-reply-all"></i> Reply-all'),
    ('fa fa-retweet', '<i class="fa fa-retweet"></i> Retweet'),
    ('fa fa-road', '<i class="fa fa-road"></i> Road'),
    ('fa fa-rocket', '<i class="fa fa-rocket"></i> Rocket'),
    ('fa fa-rss', '<i class="fa fa-rss"></i> Rss'),
    ('fa fa-rss-square', '<i class="fa fa-rss-square"></i> Rss-square'),
    ('fa fa-search', '<i class="fa fa-search"></i> Search'),
    ('fa fa-search-minus', '<i class="fa fa-search-minus"></i> Search-minus'),
    ('fa fa-search-plus', '<i class="fa fa-search-plus"></i> Search-plus'),
    ('fa fa-send', '<i class="fa fa-send"></i> Send'),
    ('fa fa-send-o', '<i class="fa fa-send-o"></i> Send-o'),
    ('fa fa-server', '<i class="fa fa-server"></i> Server'),
    ('fa fa-share', '<i class="fa fa-share"></i> Share'),
    ('fa fa-share-alt', '<i class="fa fa-share-alt"></i> Share-alt'),
    ('fa fa-share-alt-square', '<i class="fa fa-share-alt-square"></i> Share-alt-square'),
    ('fa fa-share-square', '<i class="fa fa-share-square"></i> Share-square'),
    ('fa fa-share-square-o', '<i class="fa fa-share-square-o"></i> Share-square-o'),
    ('fa fa-shield', '<i class="fa fa-shield"></i> Shield'),
    ('fa fa-ship', '<i class="fa fa-ship"></i> Ship'),
    ('fa fa-shopping-cart', '<i class="fa fa-shopping-cart"></i> Shopping-cart'),
    ('fa fa-sign-in', '<i class="fa fa-sign-in"></i> Sign-in'),
    ('fa fa-sign-out', '<i class="fa fa-sign-out"></i> Sign-out'),
    ('fa fa-signal', '<i class="fa fa-signal"></i> Signal'),
    ('fa fa-sitemap', '<i class="fa fa-sitemap"></i> Sitemap'),
    ('fa fa-sliders', '<i class="fa fa-sliders"></i> Sliders'),
    ('fa fa-smile-o', '<i class="fa fa-smile-o"></i> Smile-o'),
    ('fa fa-soccer-ball-o', '<i class="fa fa-soccer-ball-o"></i> Soccer-ball-o'),
    ('fa fa-sort', '<i class="fa fa-sort"></i> Sort'),
    ('fa fa-sort-alpha-asc', '<i class="fa fa-sort-alpha-asc"></i> Sort-alpha-asc'),
    ('fa fa-sort-alpha-desc', '<i class="fa fa-sort-alpha-desc"></i> Sort-alpha-desc'),
    ('fa fa-sort-amount-asc', '<i class="fa fa-sort-amount-asc"></i> Sort-amount-asc'),
    ('fa fa-sort-amount-desc', '<i class="fa fa-sort-amount-desc"></i> Sort-amount-desc'),
    ('fa fa-sort-asc', '<i class="fa fa-sort-asc"></i> Sort-asc'),
    ('fa fa-sort-desc', '<i class="fa fa-sort-desc"></i> Sort-desc'),
    ('fa fa-sort-down', '<i class="fa fa-sort-down"></i> Sort-down'),
    ('fa fa-sort-numeric-asc', '<i class="fa fa-sort-numeric-asc"></i> Sort-numeric-asc'),
    ('fa fa-sort-numeric-desc', '<i class="fa fa-sort-numeric-desc"></i> Sort-numeric-desc'),
    ('fa fa-sort-up', '<i class="fa fa-sort-up"></i> Sort-up'),
    ('fa fa-space-shuttle', '<i class="fa fa-space-shuttle"></i> Space-shuttle'),
    ('fa fa-spinner', '<i class="fa fa-spinner"></i> Spinner'),
    ('fa fa-spoon', '<i class="fa fa-spoon"></i> Spoon'),
    ('fa fa-square', '<i class="fa fa-square"></i> Square'),
    ('fa fa-square-o', '<i class="fa fa-square-o"></i> Square-o'),
    ('fa fa-star', '<i class="fa fa-star"></i> Star'),
    ('fa fa-star-half', '<i class="fa fa-star-half"></i> Star-half'),
    ('fa fa-star-half-empty', '<i class="fa fa-star-half-empty"></i> Star-half-empty'),
    ('fa fa-star-half-full', '<i class="fa fa-star-half-full"></i> Star-half-full'),
    ('fa fa-star-half-o', '<i class="fa fa-star-half-o"></i> Star-half-o'),
    ('fa fa-star-o', '<i class="fa fa-star-o"></i> Star-o'),
    ('fa fa-street-view', '<i class="fa fa-street-view"></i> Street-view'),
    ('fa fa-suitcase', '<i class="fa fa-suitcase"></i> Suitcase'),
    ('fa fa-sun-o', '<i class="fa fa-sun-o"></i> Sun-o'),
    ('fa fa-support', '<i class="fa fa-support"></i> Support'),
    ('fa fa-tablet', '<i class="fa fa-tablet"></i> Tablet'),
    ('fa fa-tachometer', '<i class="fa fa-tachometer"></i> Tachometer'),
    ('fa fa-tag', '<i class="fa fa-tag"></i> Tag'),
    ('fa fa-tags', '<i class="fa fa-tags"></i> Tags'),
    ('fa fa-tasks', '<i class="fa fa-tasks"></i> Tasks'),
    ('fa fa-taxi', '<i class="fa fa-taxi"></i> Taxi'),
    ('fa fa-terminal', '<i class="fa fa-terminal"></i> Terminal'),
    ('fa fa-thumb-tack', '<i class="fa fa-thumb-tack"></i> Thumb-tack'),
    ('fa fa-thumbs-down', '<i class="fa fa-thumbs-down"></i> Thumbs-down'),
    ('fa fa-thumbs-o-down', '<i class="fa fa-thumbs-o-down"></i> Thumbs-o-down'),
    ('fa fa-thumbs-o-up', '<i class="fa fa-thumbs-o-up"></i> Thumbs-o-up'),
    ('fa fa-thumbs-up', '<i class="fa fa-thumbs-up"></i> Thumbs-up'),
    ('fa fa-ticket', '<i class="fa fa-ticket"></i> Ticket'),
    ('fa fa-times', '<i class="fa fa-times"></i> Times'),
    ('fa fa-times-circle', '<i class="fa fa-times-circle"></i> Times-circle'),
    ('fa fa-times-circle-o', '<i class="fa fa-times-circle-o"></i> Times-circle-o'),
    ('fa fa-tint', '<i class="fa fa-tint"></i> Tint'),
    ('fa fa-toggle-down', '<i class="fa fa-toggle-down"></i> Toggle-down'),
    ('fa fa-toggle-left', '<i class="fa fa-toggle-left"></i> Toggle-left'),
    ('fa fa-toggle-off', '<i class="fa fa-toggle-off"></i> Toggle-off'),
    ('fa fa-toggle-on', '<i class="fa fa-toggle-on"></i> Toggle-on'),
    ('fa fa-toggle-right', '<i class="fa fa-toggle-right"></i> Toggle-right'),
    ('fa fa-toggle-up', '<i class="fa fa-toggle-up"></i> Toggle-up'),
    ('fa fa-trash', '<i class="fa fa-trash"></i> Trash'),
    ('fa fa-trash-o', '<i class="fa fa-trash-o"></i> Trash-o'),
    ('fa fa-tree', '<i class="fa fa-tree"></i> Tree'),
    ('fa fa-trophy', '<i class="fa fa-trophy"></i> Trophy'),
    ('fa fa-truck', '<i class="fa fa-truck"></i> Truck'),
    ('fa fa-tty', '<i class="fa fa-tty"></i> Tty'),
    ('fa fa-umbrella', '<i class="fa fa-umbrella"></i> Umbrella'),
    ('fa fa-university', '<i class="fa fa-university"></i> University'),
    ('fa fa-unlock', '<i class="fa fa-unlock"></i> Unlock'),
    ('fa fa-unlock-alt', '<i class="fa fa-unlock-alt"></i> Unlock-alt'),
    ('fa fa-unsorted', '<i class="fa fa-unsorted"></i> Unsorted'),
    ('fa fa-upload', '<i class="fa fa-upload"></i> Upload'),
    ('fa fa-user', '<i class="fa fa-user"></i> User'),
    ('fa fa-user-plus', '<i class="fa fa-user-plus"></i> User-plus'),
    ('fa fa-user-secret', '<i class="fa fa-user-secret"></i> User-secret'),
    ('fa fa-user-times', '<i class="fa fa-user-times"></i> User-times'),
    ('fa fa-users', '<i class="fa fa-users"></i> Users'),
    ('fa fa-video-camera', '<i class="fa fa-video-camera"></i> Video-camera'),
    ('fa fa-volume-down', '<i class="fa fa-volume-down"></i> Volume-down'),
    ('fa fa-volume-off', '<i class="fa fa-volume-off"></i> Volume-off'),
    ('fa fa-volume-up', '<i class="fa fa-volume-up"></i> Volume-up'),
    ('fa fa-warning', '<i class="fa fa-warning"></i> Warning'),
    ('fa fa-wheelchair', '<i class="fa fa-wheelchair"></i> Wheelchair'),
    ('fa fa-wifi', '<i class="fa fa-wifi"></i> Wifi'),
    ('fa fa-wrench', '<i class="fa fa-wrench"></i> Wrench'),
    ('fa fa-hand-o-down', '<i class="fa fa-hand-o-down"></i> Hand-o-down'),
    ('fa fa-hand-o-left', '<i class="fa fa-hand-o-left"></i> Hand-o-left'),
    ('fa fa-hand-o-right', '<i class="fa fa-hand-o-right"></i> Hand-o-right'),
    ('fa fa-hand-o-up', '<i class="fa fa-hand-o-up"></i> Hand-o-up'),
    ('fa fa-ambulance', '<i class="fa fa-ambulance"></i> Ambulance'),
    ('fa fa-subway', '<i class="fa fa-subway"></i> Subway'),
    ('fa fa-train', '<i class="fa fa-train"></i> Train'),
    ('fa fa-intersex', '<i class="fa fa-intersex"></i> Intersex'),
    ('fa fa-mars', '<i class="fa fa-mars"></i> Mars'),
    ('fa fa-mars-double', '<i class="fa fa-mars-double"></i> Mars-double'),
    ('fa fa-mars-stroke', '<i class="fa fa-mars-stroke"></i> Mars-stroke'),
    ('fa fa-mars-stroke-h', '<i class="fa fa-mars-stroke-h"></i> Mars-stroke-h'),
    ('fa fa-mars-stroke-v', '<i class="fa fa-mars-stroke-v"></i> Mars-stroke-v'),
    ('fa fa-mercury', '<i class="fa fa-mercury"></i> Mercury'),
    ('fa fa-neuter', '<i class="fa fa-neuter"></i> Neuter'),
    ('fa fa-transgender', '<i class="fa fa-transgender"></i> Transgender'),
    ('fa fa-transgender-alt', '<i class="fa fa-transgender-alt"></i> Transgender-alt'),
    ('fa fa-venus', '<i class="fa fa-venus"></i> Venus'),
    ('fa fa-venus-double', '<i class="fa fa-venus-double"></i> Venus-double'),
    ('fa fa-venus-mars', '<i class="fa fa-venus-mars"></i> Venus-mars'),
    ('fa fa-file', '<i class="fa fa-file"></i> File'),
    ('fa fa-file-o', '<i class="fa fa-file-o"></i> File-o'),
    ('fa fa-file-text', '<i class="fa fa-file-text"></i> File-text'),
    ('fa fa-file-text-o', '<i class="fa fa-file-text-o"></i> File-text-o'),
    ('fa fa-cc-amex', '<i class="fa fa-cc-amex"></i> Cc-amex'),
    ('fa fa-cc-discover', '<i class="fa fa-cc-discover"></i> Cc-discover'),
    ('fa fa-cc-mastercard', '<i class="fa fa-cc-mastercard"></i> Cc-mastercard'),
    ('fa fa-cc-paypal', '<i class="fa fa-cc-paypal"></i> Cc-paypal'),
    ('fa fa-cc-stripe', '<i class="fa fa-cc-stripe"></i> Cc-stripe'),
    ('fa fa-cc-visa', '<i class="fa fa-cc-visa"></i> Cc-visa'),
    ('fa fa-google-wallet', '<i class="fa fa-google-wallet"></i> Google-wallet'),
    ('fa fa-paypal', '<i class="fa fa-paypal"></i> Paypal'),
    ('fa fa-bitcoin', '<i class="fa fa-bitcoin"></i> Bitcoin'),
    ('fa fa-btc', '<i class="fa fa-btc"></i> Btc'),
    ('fa fa-cny', '<i class="fa fa-cny"></i> Cny'),
    ('fa fa-dollar', '<i class="fa fa-dollar"></i> Dollar'),
    ('fa fa-eur', '<i class="fa fa-eur"></i> Eur'),
    ('fa fa-euro', '<i class="fa fa-euro"></i> Euro'),
    ('fa fa-gbp', '<i class="fa fa-gbp"></i> Gbp'),
    ('fa fa-ils', '<i class="fa fa-ils"></i> Ils'),
    ('fa fa-inr', '<i class="fa fa-inr"></i> Inr'),
    ('fa fa-jpy', '<i class="fa fa-jpy"></i> Jpy'),
    ('fa fa-krw', '<i class="fa fa-krw"></i> Krw'),
    ('fa fa-rmb', '<i class="fa fa-rmb"></i> Rmb'),
    ('fa fa-rouble', '<i class="fa fa-rouble"></i> Rouble'),
    ('fa fa-rub', '<i class="fa fa-rub"></i> Rub'),
    ('fa fa-ruble', '<i class="fa fa-ruble"></i> Ruble'),
    ('fa fa-rupee', '<i class="fa fa-rupee"></i> Rupee'),
    ('fa fa-shekel', '<i class="fa fa-shekel"></i> Shekel'),
    ('fa fa-sheqel', '<i class="fa fa-sheqel"></i> Sheqel'),
    ('fa fa-try', '<i class="fa fa-try"></i> Try'),
    ('fa fa-turkish-lira', '<i class="fa fa-turkish-lira"></i> Turkish-lira'),
    ('fa fa-usd', '<i class="fa fa-usd"></i> Usd'),
    ('fa fa-won', '<i class="fa fa-won"></i> Won'),
    ('fa fa-yen', '<i class="fa fa-yen"></i> Yen'),
    ('fa fa-align-center', '<i class="fa fa-align-center"></i> Align-center'),
    ('fa fa-align-justify', '<i class="fa fa-align-justify"></i> Align-justify'),
    ('fa fa-align-left', '<i class="fa fa-align-left"></i> Align-left'),
    ('fa fa-align-right', '<i class="fa fa-align-right"></i> Align-right'),
    ('fa fa-bold', '<i class="fa fa-bold"></i> Bold'),
    ('fa fa-chain', '<i class="fa fa-chain"></i> Chain'),
    ('fa fa-chain-broken', '<i class="fa fa-chain-broken"></i> Chain-broken'),
    ('fa fa-clipboard', '<i class="fa fa-clipboard"></i> Clipboard'),
    ('fa fa-columns', '<i class="fa fa-columns"></i> Columns'),
    ('fa fa-copy', '<i class="fa fa-copy"></i> Copy'),
    ('fa fa-cut', '<i class="fa fa-cut"></i> Cut'),
    ('fa fa-dedent', '<i class="fa fa-dedent"></i> Dedent'),
    ('fa fa-files-o', '<i class="fa fa-files-o"></i> Files-o'),
    ('fa fa-floppy-o', '<i class="fa fa-floppy-o"></i> Floppy-o'),
    ('fa fa-font', '<i class="fa fa-font"></i> Font'),
    ('fa fa-header', '<i class="fa fa-header"></i> Header'),
    ('fa fa-indent', '<i class="fa fa-indent"></i> Indent'),
    ('fa fa-italic', '<i class="fa fa-italic"></i> Italic'),
    ('fa fa-link', '<i class="fa fa-link"></i> Link'),
    ('fa fa-list', '<i class="fa fa-list"></i> List'),
    ('fa fa-list-alt', '<i class="fa fa-list-alt"></i> List-alt'),
    ('fa fa-list-ol', '<i class="fa fa-list-ol"></i> List-ol'),
    ('fa fa-list-ul', '<i class="fa fa-list-ul"></i> List-ul'),
    ('fa fa-outdent', '<i class="fa fa-outdent"></i> Outdent'),
    ('fa fa-paperclip', '<i class="fa fa-paperclip"></i> Paperclip'),
    ('fa fa-paragraph', '<i class="fa fa-paragraph"></i> Paragraph'),
    ('fa fa-paste', '<i class="fa fa-paste"></i> Paste'),
    ('fa fa-repeat', '<i class="fa fa-repeat"></i> Repeat'),
    ('fa fa-rotate-left', '<i class="fa fa-rotate-left"></i> Rotate-left'),
    ('fa fa-rotate-right', '<i class="fa fa-rotate-right"></i> Rotate-right'),
    ('fa fa-save', '<i class="fa fa-save"></i> Save'),
    ('fa fa-scissors', '<i class="fa fa-scissors"></i> Scissors'),
    ('fa fa-strikethrough', '<i class="fa fa-strikethrough"></i> Strikethrough'),
    ('fa fa-subscript', '<i class="fa fa-subscript"></i> Subscript'),
    ('fa fa-superscript', '<i class="fa fa-superscript"></i> Superscript'),
    ('fa fa-table', '<i class="fa fa-table"></i> Table'),
    ('fa fa-text-height', '<i class="fa fa-text-height"></i> Text-height'),
    ('fa fa-text-width', '<i class="fa fa-text-width"></i> Text-width'),
    ('fa fa-th', '<i class="fa fa-th"></i> Th'),
    ('fa fa-th-large', '<i class="fa fa-th-large"></i> Th-large'),
    ('fa fa-th-list', '<i class="fa fa-th-list"></i> Th-list'),
    ('fa fa-underline', '<i class="fa fa-underline"></i> Underline'),
    ('fa fa-undo', '<i class="fa fa-undo"></i> Undo'),
    ('fa fa-unlink', '<i class="fa fa-unlink"></i> Unlink'),
    ('fa fa-angle-double-down', '<i class="fa fa-angle-double-down"></i> Angle-double-down'),
    ('fa fa-angle-double-left', '<i class="fa fa-angle-double-left"></i> Angle-double-left'),
    ('fa fa-angle-double-right', '<i class="fa fa-angle-double-right"></i> Angle-double-right'),
    ('fa fa-angle-double-up', '<i class="fa fa-angle-double-up"></i> Angle-double-up'),
    ('fa fa-angle-down', '<i class="fa fa-angle-down"></i> Angle-down'),
    ('fa fa-angle-left', '<i class="fa fa-angle-left"></i> Angle-left'),
    ('fa fa-angle-right', '<i class="fa fa-angle-right"></i> Angle-right'),
    ('fa fa-angle-up', '<i class="fa fa-angle-up"></i> Angle-up'),
    ('fa fa-arrow-circle-down', '<i class="fa fa-arrow-circle-down"></i> Arrow-circle-down'),
    ('fa fa-arrow-circle-left', '<i class="fa fa-arrow-circle-left"></i> Arrow-circle-left'),
    ('fa fa-arrow-circle-o-down', '<i class="fa fa-arrow-circle-o-down"></i> Arrow-circle-o-down'),
    ('fa fa-arrow-circle-o-left', '<i class="fa fa-arrow-circle-o-left"></i> Arrow-circle-o-left'),
    ('fa fa-arrow-circle-o-right', '<i class="fa fa-arrow-circle-o-right"></i> Arrow-circle-o-right'),
    ('fa fa-arrow-circle-o-up', '<i class="fa fa-arrow-circle-o-up"></i> Arrow-circle-o-up'),
    ('fa fa-arrow-circle-right', '<i class="fa fa-arrow-circle-right"></i> Arrow-circle-right'),
    ('fa fa-arrow-circle-up', '<i class="fa fa-arrow-circle-up"></i> Arrow-circle-up'),
    ('fa fa-arrow-down', '<i class="fa fa-arrow-down"></i> Arrow-down'),
    ('fa fa-arrow-left', '<i class="fa fa-arrow-left"></i> Arrow-left'),
    ('fa fa-arrow-right', '<i class="fa fa-arrow-right"></i> Arrow-right'),
    ('fa fa-arrow-up', '<i class="fa fa-arrow-up"></i> Arrow-up'),
    ('fa fa-arrows-alt', '<i class="fa fa-arrows-alt"></i> Arrows-alt'),
    ('fa fa-caret-down', '<i class="fa fa-caret-down"></i> Caret-down'),
    ('fa fa-caret-left', '<i class="fa fa-caret-left"></i> Caret-left'),
    ('fa fa-caret-right', '<i class="fa fa-caret-right"></i> Caret-right'),
    ('fa fa-caret-up', '<i class="fa fa-caret-up"></i> Caret-up'),
    ('fa fa-chevron-circle-down', '<i class="fa fa-chevron-circle-down"></i> Chevron-circle-down'),
    ('fa fa-chevron-circle-left', '<i class="fa fa-chevron-circle-left"></i> Chevron-circle-left'),
    ('fa fa-chevron-circle-right', '<i class="fa fa-chevron-circle-right"></i> Chevron-circle-right'),
    ('fa fa-chevron-circle-up', '<i class="fa fa-chevron-circle-up"></i> Chevron-circle-up'),
    ('fa fa-chevron-down', '<i class="fa fa-chevron-down"></i> Chevron-down'),
    ('fa fa-chevron-left', '<i class="fa fa-chevron-left"></i> Chevron-left'),
    ('fa fa-chevron-right', '<i class="fa fa-chevron-right"></i> Chevron-right'),
    ('fa fa-chevron-up', '<i class="fa fa-chevron-up"></i> Chevron-up'),
    ('fa fa-long-arrow-down', '<i class="fa fa-long-arrow-down"></i> Long-arrow-down'),
    ('fa fa-long-arrow-left', '<i class="fa fa-long-arrow-left"></i> Long-arrow-left'),
    ('fa fa-long-arrow-right', '<i class="fa fa-long-arrow-right"></i> Long-arrow-right'),
    ('fa fa-long-arrow-up', '<i class="fa fa-long-arrow-up"></i> Long-arrow-up'),
    ('fa fa-backward', '<i class="fa fa-backward"></i> Backward'),
    ('fa fa-compress', '<i class="fa fa-compress"></i> Compress'),
    ('fa fa-eject', '<i class="fa fa-eject"></i> Eject'),
    ('fa fa-expand', '<i class="fa fa-expand"></i> Expand'),
    ('fa fa-fast-backward', '<i class="fa fa-fast-backward"></i> Fast-backward'),
    ('fa fa-fast-forward', '<i class="fa fa-fast-forward"></i> Fast-forward'),
    ('fa fa-forward', '<i class="fa fa-forward"></i> Forward'),
    ('fa fa-pause', '<i class="fa fa-pause"></i> Pause'),
    ('fa fa-play', '<i class="fa fa-play"></i> Play'),
    ('fa fa-play-circle', '<i class="fa fa-play-circle"></i> Play-circle'),
    ('fa fa-play-circle-o', '<i class="fa fa-play-circle-o"></i> Play-circle-o'),
    ('fa fa-step-backward', '<i class="fa fa-step-backward"></i> Step-backward'),
    ('fa fa-step-forward', '<i class="fa fa-step-forward"></i> Step-forward'),
    ('fa fa-stop', '<i class="fa fa-stop"></i> Stop'),
    ('fa fa-youtube-play', '<i class="fa fa-youtube-play"></i> Youtube-play'),
    ('fa fa-adn', '<i class="fa fa-adn"></i> Adn'),
    ('fa fa-android', '<i class="fa fa-android"></i> Android'),
    ('fa fa-angellist', '<i class="fa fa-angellist"></i> Angellist'),
    ('fa fa-apple', '<i class="fa fa-apple"></i> Apple'),
    ('fa fa-behance', '<i class="fa fa-behance"></i> Behance'),
    ('fa fa-behance-square', '<i class="fa fa-behance-square"></i> Behance-square'),
    ('fa fa-bitbucket', '<i class="fa fa-bitbucket"></i> Bitbucket'),
    ('fa fa-bitbucket-square', '<i class="fa fa-bitbucket-square"></i> Bitbucket-square'),
    ('fa fa-buysellads', '<i class="fa fa-buysellads"></i> Buysellads'),
    ('fa fa-codepen', '<i class="fa fa-codepen"></i> Codepen'),
    ('fa fa-connectdevelop', '<i class="fa fa-connectdevelop"></i> Connectdevelop'),
    ('fa fa-css3', '<i class="fa fa-css3"></i> Css3'),
    ('fa fa-dashcube', '<i class="fa fa-dashcube"></i> Dashcube'),
    ('fa fa-delicious', '<i class="fa fa-delicious"></i> Delicious'),
    ('fa fa-deviantart', '<i class="fa fa-deviantart"></i> Deviantart'),
    ('fa fa-digg', '<i class="fa fa-digg"></i> Digg'),
    ('fa fa-dribbble', '<i class="fa fa-dribbble"></i> Dribbble'),
    ('fa fa-dropbox', '<i class="fa fa-dropbox"></i> Dropbox'),
    ('fa fa-drupal', '<i class="fa fa-drupal"></i> Drupal'),
    ('fa fa-empire', '<i class="fa fa-empire"></i> Empire'),
    ('fa fa-facebook', '<i class="fa fa-facebook"></i> Facebook'),
    ('fa fa-facebook-f', '<i class="fa fa-facebook-f"></i> Facebook-f'),
    ('fa fa-facebook-official', '<i class="fa fa-facebook-official"></i> Facebook-official'),
    ('fa fa-facebook-square', '<i class="fa fa-facebook-square"></i> Facebook-square'),
    ('fa fa-flickr', '<i class="fa fa-flickr"></i> Flickr'),
    ('fa fa-forumbee', '<i class="fa fa-forumbee"></i> Forumbee'),
    ('fa fa-foursquare', '<i class="fa fa-foursquare"></i> Foursquare'),
    ('fa fa-ge', '<i class="fa fa-ge"></i> Ge'),
    ('fa fa-git', '<i class="fa fa-git"></i> Git'),
    ('fa fa-git-square', '<i class="fa fa-git-square"></i> Git-square'),
    ('fa fa-github', '<i class="fa fa-github"></i> Github'),
    ('fa fa-github-alt', '<i class="fa fa-github-alt"></i> Github-alt'),
    ('fa fa-github-square', '<i class="fa fa-github-square"></i> Github-square'),
    ('fa fa-gittip', '<i class="fa fa-gittip"></i> Gittip'),
    ('fa fa-google', '<i class="fa fa-google"></i> Google'),
    ('fa fa-google-plus', '<i class="fa fa-google-plus"></i> Google-plus'),
    ('fa fa-google-plus-square', '<i class="fa fa-google-plus-square"></i> Google-plus-square'),
    ('fa fa-gratipay', '<i class="fa fa-gratipay"></i> Gratipay'),
    ('fa fa-hacker-news', '<i class="fa fa-hacker-news"></i> Hacker-news'),
    ('fa fa-html5', '<i class="fa fa-html5"></i> Html5'),
    ('fa fa-instagram', '<i class="fa fa-instagram"></i> Instagram'),
    ('fa fa-ioxhost', '<i class="fa fa-ioxhost"></i> Ioxhost'),
    ('fa fa-joomla', '<i class="fa fa-joomla"></i> Joomla'),
    ('fa fa-jsfiddle', '<i class="fa fa-jsfiddle"></i> Jsfiddle'),
    ('fa fa-lastfm', '<i class="fa fa-lastfm"></i> Lastfm'),
    ('fa fa-lastfm-square', '<i class="fa fa-lastfm-square"></i> Lastfm-square'),
    ('fa fa-leanpub', '<i class="fa fa-leanpub"></i> Leanpub'),
    ('fa fa-linkedin', '<i class="fa fa-linkedin"></i> Linkedin'),
    ('fa fa-linkedin-square', '<i class="fa fa-linkedin-square"></i> Linkedin-square'),
    ('fa fa-linux', '<i class="fa fa-linux"></i> Linux'),
    ('fa fa-maxcdn', '<i class="fa fa-maxcdn"></i> Maxcdn'),
    ('fa fa-meanpath', '<i class="fa fa-meanpath"></i> Meanpath'),
    ('fa fa-medium', '<i class="fa fa-medium"></i> Medium'),
    ('fa fa-openid', '<i class="fa fa-openid"></i> Openid'),
    ('fa fa-pagelines', '<i class="fa fa-pagelines"></i> Pagelines'),
    ('fa fa-pied-piper', '<i class="fa fa-pied-piper"></i> Pied-piper'),
    ('fa fa-pied-piper-alt', '<i class="fa fa-pied-piper-alt"></i> Pied-piper-alt'),
    ('fa fa-pinterest', '<i class="fa fa-pinterest"></i> Pinterest'),
    ('fa fa-pinterest-p', '<i class="fa fa-pinterest-p"></i> Pinterest-p'),
    ('fa fa-pinterest-square', '<i class="fa fa-pinterest-square"></i> Pinterest-square'),
    ('fa fa-qq', '<i class="fa fa-qq"></i> Qq'),
    ('fa fa-ra', '<i class="fa fa-ra"></i> Ra'),
    ('fa fa-rebel', '<i class="fa fa-rebel"></i> Rebel'),
    ('fa fa-reddit', '<i class="fa fa-reddit"></i> Reddit'),
    ('fa fa-reddit-square', '<i class="fa fa-reddit-square"></i> Reddit-square'),
    ('fa fa-renren', '<i class="fa fa-renren"></i> Renren'),
    ('fa fa-sellsy', '<i class="fa fa-sellsy"></i> Sellsy'),
    ('fa fa-shirtsinbulk', '<i class="fa fa-shirtsinbulk"></i> Shirtsinbulk'),
    ('fa fa-simplybuilt', '<i class="fa fa-simplybuilt"></i> Simplybuilt'),
    ('fa fa-skyatlas', '<i class="fa fa-skyatlas"></i> Skyatlas'),
    ('fa fa-skype', '<i class="fa fa-skype"></i> Skype'),
    ('fa fa-slack', '<i class="fa fa-slack"></i> Slack'),
    ('fa fa-slideshare', '<i class="fa fa-slideshare"></i> Slideshare'),
    ('fa fa-soundcloud', '<i class="fa fa-soundcloud"></i> Soundcloud'),
    ('fa fa-spotify', '<i class="fa fa-spotify"></i> Spotify'),
    ('fa fa-stack-exchange', '<i class="fa fa-stack-exchange"></i> Stack-exchange'),
    ('fa fa-stack-overflow', '<i class="fa fa-stack-overflow"></i> Stack-overflow'),
    ('fa fa-steam', '<i class="fa fa-steam"></i> Steam'),
    ('fa fa-steam-square', '<i class="fa fa-steam-square"></i> Steam-square'),
    ('fa fa-stumbleupon', '<i class="fa fa-stumbleupon"></i> Stumbleupon'),
    ('fa fa-stumbleupon-circle', '<i class="fa fa-stumbleupon-circle"></i> Stumbleupon-circle'),
    ('fa fa-tencent-weibo', '<i class="fa fa-tencent-weibo"></i> Tencent-weibo'),
    ('fa fa-trello', '<i class="fa fa-trello"></i> Trello'),
    ('fa fa-tumblr', '<i class="fa fa-tumblr"></i> Tumblr'),
    ('fa fa-tumblr-square', '<i class="fa fa-tumblr-square"></i> Tumblr-square'),
    ('fa fa-twitch', '<i class="fa fa-twitch"></i> Twitch'),
    ('fa fa-twitter', '<i class="fa fa-twitter"></i> Twitter'),
    ('fa fa-twitter-square', '<i class="fa fa-twitter-square"></i> Twitter-square'),
    ('fa fa-viacoin', '<i class="fa fa-viacoin"></i> Viacoin'),
    ('fa fa-vimeo-square', '<i class="fa fa-vimeo-square"></i> Vimeo-square'),
    ('fa fa-vine', '<i class="fa fa-vine"></i> Vine'),
    ('fa fa-vk', '<i class="fa fa-vk"></i> Vk'),
    ('fa fa-wechat', '<i class="fa fa-wechat"></i> Wechat'),
    ('fa fa-weibo', '<i class="fa fa-weibo"></i> Weibo'),
    ('fa fa-weixin', '<i class="fa fa-weixin"></i> Weixin'),
    ('fa fa-whatsapp', '<i class="fa fa-whatsapp"></i> Whatsapp'),
    ('fa fa-windows', '<i class="fa fa-windows"></i> Windows'),
    ('fa fa-wordpress', '<i class="fa fa-wordpress"></i> Wordpress'),
    ('fa fa-xing', '<i class="fa fa-xing"></i> Xing'),
    ('fa fa-xing-square', '<i class="fa fa-xing-square"></i> Xing-square'),
    ('fa fa-y-combinator-square', '<i class="fa fa-y-combinator-square"></i> Y-combinator-square'),
    ('fa fa-yahoo', '<i class="fa fa-yahoo"></i> Yahoo'),
    ('fa fa-yc-square', '<i class="fa fa-yc-square"></i> Yc-square'),
    ('fa fa-yelp', '<i class="fa fa-yelp"></i> Yelp'),
    ('fa fa-youtube', '<i class="fa fa-youtube"></i> Youtube'),
    ('fa fa-youtube-square', '<i class="fa fa-youtube-square"></i> Youtube-square'),
    ('fa fa-h-square', '<i class="fa fa-h-square"></i> H-square'),
    ('fa fa-hospital-o', '<i class="fa fa-hospital-o"></i> Hospital-o'),
    ('fa fa-medkit', '<i class="fa fa-medkit"></i> Medkit'),
    ('fa fa-stethoscope', '<i class="fa fa-stethoscope"></i> Stethoscope'),
    ('fa fa-user-md', '<i class="fa fa-user-md"></i> User-md'),
]
