{% load i18n %}

<aside class="main-sidebar">
    <section class="sidebar">
        <!-- sidebar menu: : style can be found in sidebar.less -->
        <ul class="sidebar-menu" data-widget="tree">
            <li class="header">{% trans "MAIN NAVIGATION" %}</li>
            {% for item in trionyx_menu_items %}
                {% include 'trionyx/base/_menu_items.html' %}
            {% endfor %}
        </ul>
    </section>
</aside>