"""[[verbose_name]] app configuration"""
from trionyx.trionyx.apps import BaseConfig


class Config(BaseConfig):
    """[[verbose_name]] configuration"""

    name = 'apps.[[name]]'
    verbose_name = '[[verbose_name]]'
