{% extends "trionyx/base.html" %}
{% load i18n %}

{% block title %}{% trans "403 Access Denied/Forbidden" %}{% endblock %}
{% block page_title %}{% trans "403 Access Denied/Forbidden" %}{% endblock %}

{% block content %}
    <div class="error-page">
        <h2 class="headline text-yellow"> 403</h2>

        <div class="error-content">
          <h3><i class="fa fa-warning text-yellow"></i> {% trans "Access Denied/Forbidden" %}</h3>

          <p>
              {% trans "The page or resource you were trying to reach is absolutely forbidden for some reason." %}
          </p>
        </div>
      </div>
{% endblock %}